@@ -132,10 +132,12 @@ geojson_location_noid_details = GeojsonLocationNoIdDetails.as_view()
 
 
 class LocationFilter(GeoFilterSet):
-    contains_properly = GeometryFilter(name='geometry', lookup_type='contains_properly')
+    contains_properly = GeometryFilter(name='geometry',
+                                       lookup_expr='contains_properly')
 
     class Meta:
         model = Location
+        fields = ['contains_properly']
 
 class GeojsonLocationContainedInGeometry(generics.ListAPIView):
     queryset = Location.objects.all()
